Asteroid = class("Asteroid")

GRAVITYCONSTANT = 50

function Asteroid:initialize(x, y, w, h, mass, world, spin)

	
	self.block = Block(x, y, w, h, world, BLOCK_CORE)
	self.block.body:setMass(mass)
	self.block.body:setAngularDamping(0)
	self.block.body:setAngularVelocity(spin)
	
	self.radius = (w * h)
	self.body = love.physics.newBody(world, x, y, "static")
	self.shape = love.physics.newCircleShape(self.radius)
	self.fixture = love.physics.newFixture(self.body, self.shape)
	self.fixture:setSensor(true)
	self.fixture:setUserData({
		parent = self,
		})
	self.type = SENSOR_CORE
	
	self.inField = {}
	
	self.x = x
	self.y = y
	
end

function Asteroid:update(dt)

	self.block:update(dt)
	
	self.body:setPosition(self.block.body:getPosition())

	self.body:setAngle(self.block.body:getAngle())
	
	self:gravitate()
	

end

function Asteroid:draw()
	
	self.block:draw()
	--love.graphics.circle("line", self.body:getX(), self.body:getY(), self.radius, 20)
	

end

function Asteroid:gravitate()
	
	for i = 1, #self.inField do
		
		if self.inField[i].type ~= SENSOR_CORE or self.inField[i].type ~= BLOCK_CORE then
		
		local vector_x, vector_y = self.body:getLocalPoint(self.inField[i].body:getPosition())
		
		local distance = math.dist(vector_x, vector_y, 0, 0)
	
		local gravity =  ((self.block.body:getMass() * self.inField[i].body:getMass()) * GRAVITYCONSTANT/(distance^2))
					
		local wold_x, world_y = self.inField[i].body:getPosition()
				
				
		if math.abs(vector_x) < math.abs(vector_y) then
			
			local vectorX, vectorY = self.body:getWorldVector(0, 1)
				
			if vector_y < 0 then
				
				self.inField[i].body:applyForce(vectorX * gravity, vectorY * gravity)
				self.block.body:applyForce(-vectorX * gravity, -vectorY * gravity, self.inField[i].body:getPosition())
				
			else
				
				self.inField[i].body:applyForce(-vectorX * gravity, -vectorY * gravity)
				self.block.body:applyForce(vectorX * gravity, vectorY * gravity, self.inField[i].body:getPosition())
			end
					
			
		elseif math.abs(vector_x) > math.abs(vector_y) then
			
			local vectorX, vectorY = self.body:getWorldVector( 1, 0)
				
			if vector_x < 0 then
				
				self.inField[i].body:applyForce(vectorX * gravity, vectorY * gravity)
				self.block.body:applyForce(-vectorX * gravity, -vectorY * gravity, self.inField[i].body:getPosition())
				
			else
				
				self.inField[i].body:applyForce(-vectorX * gravity, -vectorY * gravity)
				self.block.body:applyForce(vectorX * gravity, vectorY * gravity, self.inField[i].body:getPosition())
					
					
			end
				
		end
		
		end
		
	end
	
end

function Asteroid:beginContact(fixture, coll)
   
   if fixture:getUserData().parent.type ~= BLOCK_CORE then
		table.insert(self.inField, fixture:getUserData().parent)
	end
	
end

function Asteroid:endContact(fixture, coll)
   
   if fixture:getUserData().parent.type ~= BLOCK_CORE then
		for i = 1, #self.inField do
			if self.inField[i] == fixture:getUserData().parent then
				table.remove(self.inField, i)
			end
		end
	end
	
end

function Asteroid:preSolve(fixture, coll)
    
end

function Asteroid:postSolve(fixture, coll)
    
end